[devel] Added PNG_{READ,WRITE}_INT_FUNCTIONS_SUPPORTED.

This allows the functions
to read and write ints to be disabled independently of PNG_USE_READ_MACROS,
which allows libpng to be built with the functions even though the default
is to use the macros - this allows applications to choose at app build
time whether or not to use macros (previously impossible because the
functions weren't in the default build.)
diff --git a/png.h b/png.h
index 2c74a2a..d9d3bc2 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.0beta19 - April 18, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.0beta19 - April 18, 2010: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -170,7 +170,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta19, April 18, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -282,7 +282,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    April 18, 2010
+ *    April 24, 2010
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -346,7 +346,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.0beta19"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.0beta19 - April 18, 2010\n"
+     " libpng version 1.5.0beta19 - April 24, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -2024,17 +2024,23 @@
       ((png_int_32)(*((buf) + 3))))
 #  endif
 #endif
+
+#ifdef PNG_READ_INT_FUNCTIONS_SUPPORTED
 extern PNG_EXPORT(png_uint_32,png_get_uint_32,(png_bytep buf),,201);
 extern PNG_EXPORT(png_uint_16,png_get_uint_16,(png_bytep buf),,202);
-#  ifdef PNG_GET_INT_32_SUPPORTED
+#endif
+#ifdef PNG_GET_INT_32_SUPPORTED
 extern PNG_EXPORT(png_int_32,png_get_int_32,(png_bytep buf),,203);
-#  endif
+#endif
+
 extern PNG_EXPORT(png_uint_32,png_get_uint_31,(png_structp png_ptr,
     png_bytep buf),,204);
 /* No png_get_int_16 -- may be added if there's a real need for it. */
 
 /* Place a 32-bit number into a buffer in PNG byte order (big-endian). */
+#ifdef PNG_WRITE_INT_FUNCTIONS_SUPPORTED
 extern PNG_EXPORT(void,png_save_uint_32,(png_bytep buf, png_uint_32 i),,205);
+#endif
 #ifdef PNG_SAVE_INT_32_SUPPORTED
 extern PNG_EXPORT(void,png_save_int_32,(png_bytep buf, png_int_32 i),,206);
 #endif
@@ -2043,8 +2049,10 @@
  * The parameter is declared unsigned int, not png_uint_16,
  * just to avoid potential problems on pre-ANSI C compilers.
  */
+#ifdef PNG_WRITE_INT_FUNCTIONS_SUPPORTED
 extern PNG_EXPORT(void,png_save_uint_16,(png_bytep buf, unsigned int i),,207);
 /* No png_save_int_16 -- may be added if there's a real need for it. */
+#endif
 
 /* The last ordinal number (this is the *last* one, the next one to
  * use is one more than this.)
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.0beta19 - April 18, 2010
+ * libpng version 1.5.0beta19 - April 24, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.0beta19 - April 18, 2010: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.0beta19 - April 24, 2010: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -170,7 +170,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta19, April 18, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta19, April 24, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5